@@ -1,4 +1,4 @@
-# $Id: Repository.pm 2427 2017-10-28 11:15:15Z guillomovitch $
+# $Id: Repository.pm 2434 2017-10-28 12:25:04Z guillomovitch $
 package Youri::Repository;
 
 =head1 NAME
@@ -16,7 +16,8 @@ use strict;
 use Carp;
 use File::Basename;
 use Youri::Package;
-use version; our $VERSION = qv('0.1.2');
+use List::MoreUtils qw(uniq);
+use version; our $VERSION = qv('0.1.3');
 
 =head1 CLASS METHODS
 
@@ -104,6 +105,21 @@ sub get_extra_arches {
 }
 
 
+=head2 get_target_arches()
+
+Return the list of additional archictectures to handle when dealing
+with noarch packages for a given target.
+
+=cut
+
+sub get_target_arches {
+    my ($self, $target) = @_;
+    croak "Not a class method" unless ref $self;
+    return $target && $self->{_arch}{$target} ? 
+        @{$self->{_arch}{$target}} : @{$self->{_extra_arches}};
+}
+
+
 =head2 get_older_revisions($package, $target, $user_context, $app_context)
 
 Get all older revisions from a package found in its installation directory, as a
@@ -186,7 +202,7 @@ sub get_revisions {
         if $self->{_verbose} > 0;
 
     my @arches = $package->get_arch() eq 'noarch' ?
-                     ( $self->get_extra_arches(), 'noarch' ) :
+                     ( $self->get_target_arches($target), 'noarch' ) :
                      ( $package->get_arch(), 'noarch' );
     my @packages = 
         map { $self->get_package_class()->new(file => $_) }
@@ -270,7 +286,8 @@ sub get_replaced_packages {
 
     # noarch packages are potentially linked from other directories
     my @arches = $package->get_arch() eq 'noarch' ?
-                 $self->get_extra_arches() : ( $package->get_arch() );
+                     ( $self->get_target_arches($target), 'noarch' ) :
+                     ( $package->get_arch(), 'noarch' );
     foreach my $arch (@arches) {
         push(@list, $self->get_older_revisions(
             $package,
@@ -286,7 +303,7 @@ sub get_replaced_packages {
         ));
     }
 
-    return @list;
+    return uniq(@list);
 }
 
 =head2 get_files($path, $pattern)
